@@ -1,12 +1,12 @@
 from __future__ import print_function
 
 import argparse
+import json
 import os
 import re
 import signal
 import subprocess
 import sys
-import json
 
 try:
     from collections.abc import MutableMapping
@@ -18,13 +18,17 @@ ROOT_DIR = os.path.abspath(os.sep)
 PROC_DIR = os.path.join(ROOT_DIR, "proc")
 PYTHON_EXE_REGEX = re.compile(r"((python)|(pypy))(\d+(\.\d+(\.\d+)?)?)?")
 NUMERIC_REGEX = re.compile(r"\s*\d+\s*")
-DEFAULT_BIN_DIRS = [os.path.join(ROOT_DIR, "usr", "bin"), os.path.join(
-    ROOT_DIR, "usr", "local", "bin")]
+DEFAULT_BIN_DIRS = [
+    os.path.join(ROOT_DIR, "usr", "bin"),
+    os.path.join(ROOT_DIR, "usr", "local", "bin"),
+]
 PY2 = sys.version[0] == "2"
 DEFAULT_PYTHON_APP_NAME = "Python Application"
 
+
 class RunMode:
     """Py2 compatible enum."""
+
     LIST = 1
     INTROSPECT = 2
     INSTALL = 3
@@ -180,7 +184,7 @@ class Process(object):
 
     @property
     def is_process_manager(self):
-        if "supervisord" in ''.join(self.command):
+        if "supervisord" in "".join(self.command):
             return True
         return False
 
@@ -216,8 +220,10 @@ class Process(object):
                             python_exes,
                         )
                     else:  # No exe dir found
-                        print("Python executable not found in base path of %s. Defaulting to %s" % (
-                            str(self.command[0]), str(sys.executable)))
+                        print(
+                            "Python executable not found in base path of %s. Defaulting to %s"
+                            % (str(self.command[0]), str(sys.executable))
+                        )
                         self._python_executable = sys.executable
 
             return self._python_executable
@@ -252,7 +258,11 @@ class Process(object):
 
     @property
     def is_instrumentable(self):
-        return self.exists and self.is_base_python_process and self.is_compatible_python_version
+        return (
+            self.exists
+            and self.is_base_python_process
+            and self.is_compatible_python_version
+        )
 
     @property
     def exists(self):
@@ -307,15 +317,22 @@ class Process(object):
             return app_name
         else:
             print(
-                "\nPlease enter an application name that is at least one character long.")
-            return self.get_app_name()
+                "\nPlease enter an application name that is at least one character long."
+            )
+            return self.get_app_name(args)
 
     def generate_newrelic_config(self, args, ini_path):
-        if not os.path.exists(ini_path) or args.yes or yes_no_input("\nnewrelic.ini file detected at %s. Would you like to overwrite it?" % str(ini_path)):
+        if (
+            not os.path.exists(ini_path)
+            or args.yes
+            or yes_no_input(
+                "\nnewrelic.ini file detected at %s. Would you like to overwrite it?"
+                % str(ini_path)
+            )
+        ):
             app_name = args.appName or self.get_app_name(args)
             subprocess.call(
-                [self.newrelic_admin, "generate-config",
-                    args.licenseKey, str(ini_path)]
+                [self.newrelic_admin, "generate-config", args.licenseKey, str(ini_path)]
             )
             with open(ini_path, "r+") as file:
                 file_text = file.read()
@@ -331,7 +348,8 @@ class Process(object):
                 dt_replaced_text = file_text.replace(replace, replace_with)
 
                 final_config = dt_replaced_text.replace(
-                    DEFAULT_PYTHON_APP_NAME, app_name)
+                    DEFAULT_PYTHON_APP_NAME, app_name
+                )
 
                 file.write(final_config)
 
@@ -351,7 +369,8 @@ class Process(object):
 
             # Accept -y flag or prompt user for choice.
             yes = args.yes or yes_no_input(
-                "\nAccept above command and restart process?")
+                "\nAccept above command and restart process?"
+            )
             if not yes:
                 print("\nContinuing introspection without restarting process...")
                 return False  # Exit if not accepted.
@@ -372,13 +391,13 @@ class Process(object):
             os.kill(self.pid, signal.SIGTERM)
 
             # Start process with modified command
-            print("Using command: %s\nRestarting process..." %
-                  " ".join(process_command))
+            print(
+                "Using command: %s\nRestarting process..." % " ".join(process_command)
+            )
 
-            subprocess.Popen(
-                process_command, env=self.environ, cwd=self.workdir)
+            subprocess.Popen(process_command, env=self.environ, cwd=self.workdir)
 
-        except:
+        except Exception:
             print("\nFailed to instrument process.")
 
         return True
@@ -386,8 +405,7 @@ class Process(object):
 
 def list_instrumentable_pids(args):
     process_tree = ProcessTree()
-    pids = [pid for pid, process in process_tree.items()
-            if process.is_instrumentable]
+    pids = [pid for pid, process in process_tree.items() if process.is_instrumentable]
 
     print(json.dumps(pids))
 
@@ -427,8 +445,7 @@ def install_pid(args):
         success = process.install(args)
 
     if not success:
-        print("\nnewrelic agent could not be installed for PID %d." %
-              process.pid)
+        print("\nnewrelic agent could not be installed for PID %d." % process.pid)
 
 
 def instrument_pid(args):
@@ -440,8 +457,7 @@ def instrument_pid(args):
         success = process.instrument(args)
 
     if not success:
-        print("\nPID %d was not restarted or instrumented." %
-              process.pid)
+        print("\nPID %d was not restarted or instrumented." % process.pid)
 
 
 def yes_no_input(question):
@@ -503,13 +519,13 @@ def choice_input(question, choices):
 def get_input(prompt):
     """Compatibility function for Python 2/3. Gets user input based on prompt."""
     if PY2:
-        return raw_input(prompt)
+        return raw_input(prompt)  # pylint: disable=E0602 # noqa: F821
     else:
         return input(prompt)
 
 
 def require_arg_defined(arg, args):
-    if getattr(args, arg) == None:
+    if getattr(args, arg) is None:
         sys.stderr.write("--%s argument is required\n" % arg)
         sys.exit(1)
 
@@ -572,10 +588,10 @@ def main():
     parser.add_argument(
         "-r",
         "--region",
-        choices=['US', 'EU', 'STAGING'],
+        choices=["US", "EU", "STAGING"],
         type=str.upper,
         help="the region to report into",
-        default=os.environ.get('NEW_RELIC_REGION', "US"),
+        default=os.environ.get("NEW_RELIC_REGION", "US"),
         dest="region",
     )
 
@@ -583,7 +599,7 @@ def main():
         "-k",
         "--licenseKey",
         help="the license key to use when reporting data",
-        default=os.environ.get('NEW_RELIC_LICENSE_KEY'),
+        default=os.environ.get("NEW_RELIC_LICENSE_KEY"),
         dest="licenseKey",
     )
 
